@@ -20,8 +20,6 @@
 #include <config.h>
 #endif
 
-#include <glib/gi18n-lib.h>
-
 #define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
 #include "weather.h"
 #include "weather-priv.h"
@@ -95,7 +93,7 @@ wx_start_open (WeatherInfo *info)
  
     msg = soup_message_new ("GET", url);
     g_signal_connect (msg, "got-chunk", G_CALLBACK (wx_got_chunk), info);
-    soup_message_set_flags (msg, SOUP_MESSAGE_OVERWRITE_CHUNKS);
+    soup_message_body_set_accumulate (msg->response_body, FALSE);
     soup_session_queue_message (info->session, msg, wx_finish, info);
     g_free (url);
 
